@@ -379,17 +379,19 @@ class Field(MetricsLayerBase, SQLReplacement):
             if to_replace == "TABLE":
                 clean_sql = clean_sql.replace("${TABLE}", view_name)
             else:
-                field = self.get_field_with_view_info(to_replace)
+                field = self.get_field_with_view_info(to_replace, specified_view=view_name)
                 sql_replace = deepcopy(field.sql) if field and field.sql else to_replace
                 clean_sql = clean_sql.replace(
                     "${" + to_replace + "}", self.replace_fields(sql_replace, view_name=field.view.name)
                 )
         return clean_sql.strip()
 
-    def get_field_with_view_info(self, field: str):
+    def get_field_with_view_info(self, field: str, specified_view: str = None):
         _, view_name, field_name = self.field_name_parts(field)
-        if view_name is None:
+        if view_name is None and specified_view is None:
             view_name = self.view.name
+        elif view_name is None and specified_view:
+            view_name = specified_view
 
         if self.view is None:
             raise AttributeError(f"You must specify which view this field is in '{self.name}'")
@@ -416,9 +418,42 @@ class Field(MetricsLayerBase, SQLReplacement):
         case_sql = "case when "
         conditions = []
         for f in filters:
-            # TODO add the advanced filter parsing here
+            # TODO more advanced parsing
+            # ref: https://docs.looker.com/reference/field-params/filters
+
             field_reference = "${" + f["field"] + "}"
-            condition = f"{field_reference} = '{f['value']}'"
+            value = f["value"]
+
+            # Handle null conditiona
+            if value == "NULL":
+                condition_value = f"is null"
+            elif value == "-NULL":
+                condition_value = f"is not null"
+
+            # Numeric parsing for less than or equal to, greater than or equal to, not equal to
+            elif value[:2] in {"=<", ">=", "<>", "!="}:
+                condition_value = f"{value[:2]} {value[2:]}"
+
+            # Numeric parsing for equal to, less than, greater than
+            elif value[0] in {"=", ">", "<"}:
+                condition_value = f"{value[0]} {value[1:]}"
+
+            # Not equal to condition for strings
+            elif value[0] == "-":
+                condition_value = f"<> '{value[1:]}'"
+
+            # Not equal to condition for strings
+            elif value[0] == "-":
+                condition_value = f"<> '{value[1:]}'"
+
+            # isin for strings
+            elif len(value.split(", ")) > 1:
+                raise NotImplementedError("TODO: Need to support array syntax in filters")
+
+            else:
+                condition_value = f"= '{value}'"
+
+            condition = f"{field_reference} {condition_value}"
             conditions.append(condition)
 
         # Add the filter conditions AND'd together
